package com.caimei365.order.controller;

import com.caimei365.order.model.ResponseJson;
import com.caimei365.order.model.dto.OrderDto;
import com.caimei365.order.service.OrderClubService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 机构订单API
 *
 * @author : Charles
 * @date : 2021/7/19
 */
@Api(tags="机构订单API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/order/club")
public class OrderClubApi {

    private final OrderClubService orderClubService;
    private final String ID_EMPTY = "订单Id不能为空！";

    /**
     * 机构确认订单
     *
     * @param orderDto {
     *                orderId      订单ID
     * }
     */
    @ApiOperation("机构确认订单（旧：/order/affirmOrder）")
    @PostMapping("/confirm")
    public ResponseJson<Void> confirmOrder(OrderDto orderDto){
        if (null == orderDto.getOrderId()) {
            return ResponseJson.error(ID_EMPTY, null);
        }
        return orderClubService.confirmMainOrder(orderDto.getOrderId());
    }

    /**
     * 机构取消订单
     *
     * @param orderDto {
     *                orderId      订单ID
     *                note         备注（订单取消原因）
     * }
     */
    @ApiOperation("机构取消订单（旧：/order/cancel）")
    @PostMapping("/cancel")
    public ResponseJson<Void> cancelOrder(OrderDto orderDto){
        if (null == orderDto.getOrderId()) {
            return ResponseJson.error(ID_EMPTY, null);
        }
        return orderClubService.cancelMainOrder(orderDto.getOrderId(), orderDto.getRemark());
    }

    /**
     * 机构删除订单
     *
     * @param orderDto {
     *                orderId      订单ID
     * }
     */
    @ApiOperation("机构删除订单（旧：/order/delete）")
    @PostMapping("/delete")
    public ResponseJson<Void> deleteOrder(OrderDto orderDto){
        if (null == orderDto.getOrderId()) {
            return ResponseJson.error(ID_EMPTY, null);
        }
        return orderClubService.deleteMainOrder(orderDto.getOrderId());
    }

    /**
     * 机构确认收货
     *
     * @param orderDto {
     *                orderId      订单ID
     * }
     */
    @ApiOperation("机构确认收货（旧：/order/affirm）")
    @PostMapping("/receive")
    public ResponseJson<Void> receiveGoods(OrderDto orderDto){
        if (null == orderDto.getOrderId()) {
            return ResponseJson.error(ID_EMPTY, null);
        }
        return orderClubService.receiveGoods(orderDto.getOrderId());
    }

}
