package com.caimei365.order.mapper;

import com.caimei365.order.model.po.BalanceRecordPo;
import com.caimei365.order.model.po.OrderPo;
import com.caimei365.order.model.po.OrderProductPo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/7/19
 */
@Mapper
public interface OrderClubMapper {
    /**
     * 根据订单Id查询订单
     * @param orderId 订单Id
     */
    OrderPo getMainOrderByOrderId(Integer orderId);
    /**
     * 根据订单Id查询订单商品列表
     * @param orderId 订单Id
     */
    List<OrderProductPo> getOrderProductList(Integer orderId);
    /**
     * 设置二手仪器已售
     * @param productId 商品Id
     */
    void updateSecondStatus(Integer productId, Integer sold);
    /**
     * 根据用户Id更新用户余额
     * @param userId 用户Id
     */
    void updateUserMoneyByUserId(double userMoney, Integer userId);
    /**
     * 根据用户Id更新用户可用余额
     * @param userId 用户Id
     */
    void updateAbleUserMoneyByUserId(double ableUserMoney, Integer userId);
    /**
     * 更新订单状态
     * @param order 主订单
     */
    void updateOrderStatus(OrderPo order);
    /**
     * 取消 余额收支记录
     * @param balanceRecord
     */
    void cancelBalanceRecord(BalanceRecordPo balanceRecord);
    /**
     * 取消 订单
     * @param order
     */
    void cancelMainOrder(OrderPo order);
    /**
     * 逻辑删除主订单
     * @param order
     */
    void deleteMainOrder(OrderPo order);
    /**
     * 逻辑删除子订单
     * @param shopOrderIds 子订单Ids
     */
    void deleteShopOrder(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 获取收款记录Id列表
     * @param orderId 订单Id
     */
    List<String> getOrderReceiptIds(Integer orderId);
    /**
     * 逻辑删除订单与收款记录关系表
     * @param orderId 订单Id
     */
    void deleteOrderReceiptRelation(Integer orderId);
    /**
     * 逻辑删除收款记录表
     * @param receiptIds 收款记录Ids
     */
    void deleteDiscernReceipt(@Param("receiptIds") List<String> receiptIds);
    /**
     * 获取付款记录Id列表
     * @param shopOrderIds 子订单Ids
     */
    List<String> getPayShopIds(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 逻辑删除订单与付款记录关系表
     * @param shopOrderIds 子订单Ids
     */
    void deletePayShopRecord(@Param("shopOrderIds") List<String> shopOrderIds);
    /**
     * 逻辑删除付款记录表
     * @param payIds 付款记录Ids
     */
    void deletePayShop(@Param("payIds") List<String> payIds);
    /**
     * 更新物流状态
     * @param orderId 订单Id
     */
    void updateLogisticsBatch(Integer orderId);
}
